==> igniteui-react-layouts-18.7.3.tgz: package/esm5/lib/igr-tool-action-checkbox.js <==
import { __extends } from "tslib";
import { IgrToolAction } from "./igr-tool-action";
import { ToolActionCheckbox } from "./ToolActionCheckbox";
import { ensureBool, brushToString, stringToBrush } from "igniteui-react-core";
var IgrToolActionCheckbox = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(IgrToolActionCheckbox, _super);
    function IgrToolActionCheckbox(props) {
        return _super.call(this, props) || this;
    }
    IgrToolActionCheckbox.prototype.createImplementation = function () {
        return new ToolActionCheckbox();
    };
    Object.defineProperty(IgrToolActionCheckbox.prototype, "i", {
        /**
                                     * @hidden
                                     */
        get: function () {
            return this._implementation;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrToolActionCheckbox.prototype, "isChecked", {
        /**
         * Gets or sets if the tool action is checked.
        */
        get: function () {
            return this.i.hb;
        },
        set: function (v) {
            this.i.hb = ensureBool(v);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrToolActionCheckbox.prototype, "uncheckedBackgroundColor", {
        /**
         * Gets or sets the background color of the checkbox when in the unchecked state.
        */
        get: function () {
            return brushToString(this.i.h1);
        },
        set: function (v) {
            this.i.h1 = stringToBrush(v);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrToolActionCheckbox.prototype, "actualUncheckedBackgroundColor", {
        /**
         * Gets the actual background color of the checkbox when in the unchecked state.
        */
        get: function () {
            return brushToString(this.i.hx);
        },
        set: function (v) {
            this.i.hx = stringToBrush(v);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrToolActionCheckbox.prototype, "checkedBackgroundColor", {
        /**
         * Gets or sets the background color of the checkbox when in the checked state.
        */
        get: function () {
            return brushToString(this.i.hz);
        },
        set: function (v) {
            this.i.hz = stringToBrush(v);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrToolActionCheckbox.prototype, "actualCheckedBackgroundColor", {
        /**
         * Gets the actual background color of the checkbox when in the checked state.
        */
        get: function () {
            return brushToString(this.i.hv);
        },
        set: function (v) {
            this.i.hv = stringToBrush(v);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrToolActionCheckbox.prototype, "uncheckedBorderColor", {
        /**
         * Gets or sets the border color of the checkbox when in the unchecked state.
        */
        get: function () {
            return brushToString(this.i.h2);
        },
        set: function (v) {
            this.i.h2 = stringToBrush(v);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrToolActionCheckbox.prototype, "actualUncheckedBorderColor", {
        /**
         * Gets the actual border color of the checkbox when in the unchecked state.
        */
        get: function () {
            return brushToString(this.i.hy);
        },
        set: function (v) {
            this.i.hy = stringToBrush(v);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrToolActionCheckbox.prototype, "checkedBorderColor", {
        /**
         * Gets or sets the border color of the checkbox when in the checked state.
        */
        get: function () {
            return brushToString(this.i.h0);
        },
        set: function (v) {
            this.i.h0 = stringToBrush(v);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrToolActionCheckbox.prototype, "actualCheckedBorderColor", {
        /**
         * Gets the actual border color of the checkbox when in the checked state.
        */
        get: function () {
            return brushToString(this.i.hw);
        },
        set: function (v) {
            this.i.hw = stringToBrush(v);
        },
        enumerable: false,
        configurable: true
    });
    return IgrToolActionCheckbox;
}(IgrToolAction));
export { IgrToolActionCheckbox };

==> igniteui-react-layouts-18.7.5.tgz: package/esm5/lib/igr-tool-action-checkbox.js <==
import { __extends } from "tslib";
import { IgrToolAction } from "./igr-tool-action";
import { ToolActionCheckbox } from "./ToolActionCheckbox";
import { ensureBool, brushToString, stringToBrush } from "igniteui-react-core";
var IgrToolActionCheckbox = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(IgrToolActionCheckbox, _super);
    function IgrToolActionCheckbox(props) {
        return _super.call(this, props) || this;
    }
    IgrToolActionCheckbox.prototype.createImplementation = function () {
        return new ToolActionCheckbox();
    };
    Object.defineProperty(IgrToolActionCheckbox.prototype, "i", {
        /**
                                     * @hidden
                                     */
        get: function () {
            return this._implementation;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrToolActionCheckbox.prototype, "isChecked", {
        /**
         * Gets or sets if the tool action is checked.
        */
        get: function () {
            return this.i.g8;
        },
        set: function (v) {
            this.i.g8 = ensureBool(v);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrToolActionCheckbox.prototype, "uncheckedBackgroundColor", {
        /**
         * Gets or sets the background color of the checkbox when in the unchecked state.
        */
        get: function () {
            return brushToString(this.i.hq);
        },
        set: function (v) {
            this.i.hq = stringToBrush(v);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrToolActionCheckbox.prototype, "actualUncheckedBackgroundColor", {
        /**
         * Gets the actual background color of the checkbox when in the unchecked state.
        */
        get: function () {
            return brushToString(this.i.hm);
        },
        set: function (v) {
            this.i.hm = stringToBrush(v);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrToolActionCheckbox.prototype, "checkedBackgroundColor", {
        /**
         * Gets or sets the background color of the checkbox when in the checked state.
        */
        get: function () {
            return brushToString(this.i.ho);
        },
        set: function (v) {
            this.i.ho = stringToBrush(v);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrToolActionCheckbox.prototype, "actualCheckedBackgroundColor", {
        /**
         * Gets the actual background color of the checkbox when in the checked state.
        */
        get: function () {
            return brushToString(this.i.hk);
        },
        set: function (v) {
            this.i.hk = stringToBrush(v);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrToolActionCheckbox.prototype, "uncheckedBorderColor", {
        /**
         * Gets or sets the border color of the checkbox when in the unchecked state.
        */
        get: function () {
            return brushToString(this.i.hr);
        },
        set: function (v) {
            this.i.hr = stringToBrush(v);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrToolActionCheckbox.prototype, "actualUncheckedBorderColor", {
        /**
         * Gets the actual border color of the checkbox when in the unchecked state.
        */
        get: function () {
            return brushToString(this.i.hn);
        },
        set: function (v) {
            this.i.hn = stringToBrush(v);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrToolActionCheckbox.prototype, "checkedBorderColor", {
        /**
         * Gets or sets the border color of the checkbox when in the checked state.
        */
        get: function () {
            return brushToString(this.i.hp);
        },
        set: function (v) {
            this.i.hp = stringToBrush(v);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrToolActionCheckbox.prototype, "actualCheckedBorderColor", {
        /**
         * Gets the actual border color of the checkbox when in the checked state.
        */
        get: function () {
            return brushToString(this.i.hl);
        },
        set: function (v) {
            this.i.hl = stringToBrush(v);
        },
        enumerable: false,
        configurable: true
    });
    return IgrToolActionCheckbox;
}(IgrToolAction));
export { IgrToolActionCheckbox };
